@@ -3,7 +3,7 @@
 # If we try to use a normal Github Actions container with
 # github-pages-deploy-action, it will fail due to inability to find git.
 
-docker run -h test.box \
+docker run -h test.krbtest.com \
        -v `pwd`:/tmp/build -w /tmp/build \
        -e KRB5_VER=${KRB5_VER:-mit} \
        -e FLAKE=${FLAKE:no} \
